
Installing
==========

----

.. image:: _static/pics/yacht.jpg

Using Pip
---------

This is the simplest method. To install Robin Stocks globally or inside a virtual environment,
open terminal and run the command::

$ pip install robin_stocks

Get The Source Code
-------------------

If you prefer to install the source code directly, it can be found `here <https://github.com/jmfernandes/robin_stocks>`_,
or you can clone the repository using::

$ git clone https://github.com/jmfernandes/robin_stocks.git

Once the file has been downloaded or cloned, cd into the directory that contains the ``setup.py`` file and install using::

$ pip install .
